==> open-xchange-usm_6.18.0.0.orig.tar.gz: open-xchange-usm-6.18.0.0/com.openexchange.usm.syncml/src/com/openexchange/usm/syncml/elements/SyncBody.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.syncml.elements;

import java.io.IOException;
import java.util.*;

import org.xmlpull.v1.*;

import com.openexchange.usm.syncml.commands.SyncMLCommand;
import com.openexchange.usm.syncml.parser.XmlPullParserUtil;

/**
 * 
 * @author afe
 *
 */
public class SyncBody extends BaseElement implements Iterable<SyncMLCommand> {
	public static final String ELEMENT_NAME = "SyncBody";

	private final List<SyncMLCommand> _commands = new ArrayList<SyncMLCommand>();
	private boolean _final;

	public SyncBody(SyncBody syncBody) {
		_final = true;
	}

	public SyncBody(XmlPullParser parser, Meta meta) throws XmlPullParserException, IOException {
		readElementStart(parser);
		readCommands(parser, meta, _commands, 0);
		_final = XmlPullParserUtil.readOptionalFlag(parser, SimpleElements.FINAL);
		readElementEnd(parser);
	}

	public String getElementName() {
		return ELEMENT_NAME;
	}

	@Override
	protected void writeContent(XmlSerializer serializer, Meta meta) throws IOException {
		for (SyncMLCommand command : _commands)
			command.write(serializer, meta);
		XmlPullParserUtil.writeOptionalFlag(serializer, SimpleElements.FINAL, _final);
	}

	public boolean isFinal() {
		return _final;
	}

	public void setFinal(boolean f) {
		_final = f;
	}

	public void addCommand(SyncMLCommand command) {
		_commands.add(command);
	}

	public Iterator<SyncMLCommand> iterator() {
		return _commands.iterator();
	}

	public List<SyncMLCommand> getCommands() {
		return _commands;
	}
}

==> open-xchange-usm_6.20.8.0.orig.tar.gz: open-xchange-usm-6.20.8.0/com.openexchange.usm.syncml/src/com/openexchange/usm/syncml/elements/SyncBody.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.syncml.elements;

import java.io.IOException;
import java.util.*;

import org.xmlpull.v1.*;

import com.openexchange.usm.syncml.commands.Status;
import com.openexchange.usm.syncml.commands.SyncMLCommand;
import com.openexchange.usm.syncml.parser.XmlPullParserUtil;

/**
 * 
 * @author afe
 *
 */
public class SyncBody extends BaseElement implements Iterable<SyncMLCommand> {
	public static final String ELEMENT_NAME = "SyncBody";

	private final List<SyncMLCommand> _commands = new ArrayList<SyncMLCommand>();
	private boolean _final;

	public SyncBody(SyncBody syncBody) {
		_final = true;
	}

	public SyncBody(XmlPullParser parser, Meta meta) throws XmlPullParserException, IOException {
		readElementStart(parser);
		readCommands(parser, meta, _commands, 0);
		_final = XmlPullParserUtil.readOptionalFlag(parser, SimpleElements.FINAL);
		readElementEnd(parser);
	}

	public String getElementName() {
		return ELEMENT_NAME;
	}

	@Override
	protected void writeContent(XmlSerializer serializer, Meta meta) throws IOException {
		for (SyncMLCommand command : _commands)
			command.write(serializer, meta);
		XmlPullParserUtil.writeOptionalFlag(serializer, SimpleElements.FINAL, _final);
	}

	public boolean isFinal() {
		return _final;
	}

	public void setFinal(boolean f) {
		_final = f;
	}

	public void addCommand(SyncMLCommand command) {
		_commands.add(command);
	}

	public Iterator<SyncMLCommand> iterator() {
		return _commands.iterator();
	}

	public List<SyncMLCommand> getCommands() {
		return _commands;
	}

	public String getDescription() {
		StringBuilder sb = new StringBuilder(256);
		char delim = '[';
		for (SyncMLCommand command : _commands) {
			if (!(command instanceof Status)) {
				sb.append(delim).append(command);
				delim = ',';
			}
		}
		if (_final)
			sb.append(delim).append("<Final>");
		else if (delim == '[')
			sb.append('[');
		return sb.append(']').toString();
	}
}
